==> billogram-foundation-3.13.10.tgz: package/modules/components/textbox/Textbox.jest.js <==
import React from 'react';
import purebem from 'purebem';
import { mount } from 'enzyme';

import Textbox from './Textbox';


const TestTextbox = Textbox({
    block: purebem.of('test-textbox'),
    displayName: 'TestTextbox'
});

test('accepts input for text type', () => {
    const onChange = jest.fn();
    const textbox = mount(
        <TestTextbox
            type="text"
            onChange={ onChange }
            value={ '' } />
    );

    textbox.simulate('change', { target: { value: 'a' } });

    expect(onChange).toHaveBeenCalledWith({ rawValue: 'a', value: 'a' });
});

test('accepts input for integer type', () => {
    const onChange = jest.fn();
    const textbox = mount(
        <TestTextbox
            type="integer"
            onChange={ onChange }
            value={ '' } />
    );

    textbox.simulate('change', { target: { value: '1' } });

    expect(onChange).toHaveBeenCalledWith({ rawValue: '1', value: 1 });
});

test('should ignore non-number related characters for integer type', () => {
    const onChange = jest.fn();
    const textbox = mount(
        <TestTextbox
            type="integer"
            onChange={ onChange }
            value={ '' } />
    );

    textbox.simulate('change', { target: { value: 'a' } });

    expect(onChange).not.toHaveBeenCalled();
});

test('accepts input for float type', () => {
    const onChange = jest.fn();
    const textbox = mount(
        <TestTextbox
            type="float"
            onChange={ onChange }
            value={ '' } />
    );

    textbox.simulate('change', { target: { value: '1' } });

    expect(onChange).toHaveBeenCalledWith({ rawValue: '1', value: 1 });
});

test('should ignore non-number related characters for float type', () => {
    const onChange = jest.fn();
    const textbox = mount(
        <TestTextbox
            type="float"
            onChange={ onChange }
            value={ '' } />
    );

    textbox.simulate('change', { target: { value: 'a' } });

    expect(onChange).not.toHaveBeenCalled();
});

==> billogram-foundation-4.8.1.tgz: package/modules/components/textbox/Textbox.jest.js <==
import React from 'react';
import purebem from 'purebem';
import { mount } from 'enzyme';

import Textbox from './Textbox';


const TestTextbox = Textbox({
    block: purebem.of('test-textbox'),
    displayName: 'TestTextbox',
});

test('accepts input for text type', () => {
    const onChange = jest.fn();
    const textbox = mount(
        <TestTextbox
            type="text"
            onChange={ onChange }
            value={ '' } />
    );

    textbox.simulate('change', { target: { value: 'a' } });

    expect(onChange).toHaveBeenCalledWith({ rawValue: 'a', value: 'a' });
});

test('accepts input for integer type', () => {
    const onChange = jest.fn();
    const textbox = mount(
        <TestTextbox
            type="integer"
            onChange={ onChange }
            value={ '' } />
    );

    textbox.simulate('change', { target: { value: '1' } });

    expect(onChange).toHaveBeenCalledWith({ rawValue: '1', value: 1 });
});

test('should ignore non-number related characters for integer type', () => {
    const onChange = jest.fn();
    const textbox = mount(
        <TestTextbox
            type="integer"
            onChange={ onChange }
            value={ '' } />
    );

    textbox.simulate('change', { target: { value: 'a' } });

    expect(onChange).not.toHaveBeenCalled();
});

test('accepts input for float type', () => {
    const onChange = jest.fn();
    const textbox = mount(
        <TestTextbox
            type="float"
            onChange={ onChange }
            value={ '' } />
    );

    textbox.simulate('change', { target: { value: '1' } });

    expect(onChange).toHaveBeenCalledWith({ rawValue: '1', value: 1 });
});

test('should ignore non-number related characters for float type', () => {
    const onChange = jest.fn();
    const textbox = mount(
        <TestTextbox
            type="float"
            onChange={ onChange }
            value={ '' } />
    );

    textbox.simulate('change', { target: { value: 'a' } });

    expect(onChange).not.toHaveBeenCalled();
});
